@@ -1,11 +1,14 @@
+from python_nicepay.constants.constantsGeneral import ConstantsGeneral
 from python_nicepay.data.builder.snap import builderAccessToken, builderVirtualAccount
 from python_nicepay.constants.constantsEndpoint import ConstantsEndpoints
 from python_nicepay.service.snapService import SnapService
 from python_nicepay.util.utilLogging import Log
+from python_nicepay.data.builder import builderEnvironment
 
 log = Log()
 
 class testVirtualAccountInquiry:
+
     bodyCreateToken = (
         builderAccessToken.BuildAccessToken()
         .setGrantType("client_credentials")
@@ -19,21 +22,27 @@ class testVirtualAccountInquiry:
     }
 
     additionalInfo = {
-        "tXidVA": "IONPAYTEST02202411130910178964",
+        "tXidVA": "_YOUR_TRANSACTION_ID_YOUR_TRANSACTION_ID",
         "totalAmount": totalAmount,
-        "trxId": "123",
+        "trxId": "NORMAL123457",
     }
 
     bodyInquiryVA = (
         builderVirtualAccount.BuildInquiryVA()
         .setPartnerServiceId("")
         .setCustomerNo("")
-        .setVirtualAccountNo("884800040910178964")
+        .setVirtualAccountNo("_YOUR_VA_NO")
         .setInquiryRequestId("")
         .setAdditionalInfo(additionalInfo)
         .build()
     )
 
+    environment = (builderEnvironment.BuildEnvironment()
+                   .isCloud(False)
+                   .isProduction(False)
+                   .build())
+
     result = SnapService.serviceTransaction(bodyCreateToken.jsonAccessToken(),
                                             bodyInquiryVA.jsonVAInquiry(),
-                                            ConstantsEndpoints.inquiryVA())
+                                            ConstantsEndpoints.inquiryVA(),
+                                            environment)
