@@ -1,11 +1,12 @@
 from python_nicepay.constants.constantsGeneral import ConstantsGeneral
+from python_nicepay.data.builder import builderEnvironment
 from python_nicepay.data.builder.v2.enterprise.dataGenerator import DataGenerator
 from python_nicepay.data.builder.v2.enterprise import builderCreditCard, builderCartData
 from python_nicepay.service.v2EnterpriseService import ServiceNicepay
 
 
 class testCreditCard:
-    amt = 10000
+    amt = 1000
     itemCartData = {
         "goods_id": "BB12345678",
         "goods_detail": "BB12345678",
@@ -28,15 +29,21 @@ class testCreditCard:
     bodyCreditCard = (
         builderCreditCard.BuildCreditCard()
         .setPayMethod(ConstantsGeneral.getPayMethodCreditCard())
-        .setRecurrOpt("1")
+        .setRecurrOpt("")
         .setInstmntMon("1")
         .setInstmntType("1")
         .setAmt(amt)
         .build()
     )
 
+    environment = (builderEnvironment.BuildEnvironment()
+                   .isCloud(False)
+                   .isProduction(False)
+                   .build())
+
     response = ServiceNicepay.serviceRequest(DataGenerator.getTransactionBody(bodyCreditCard.jsonCreditCard(),
-                                                                              bodyCartData.jsonCartData()))
+                                                                              bodyCartData.jsonCartData()),
+                                                                              environment)
 
 
 
